==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/IDC.php <==
<?php /* Copyright (C) 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2007, 2008 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<p>Swedish personal number calculator</p>

<table cellspacing="0" cellpadding="0">
  <tr>
    <td>
<form method='post'>

<table>
  <tr>
    <td>Year</td>
    <td>Month</td>
    <td>Day</td>
  <td>Birthnumber (odd third digit for males)</td>
  </tr>
  <tr>
    <td>

<select name="year">

			<option value="10">1910</option>
<option value="11">1911</option>
<option value="12">1912</option>
<option value="13">1913</option>
<option value="14">1914</option>
<option value="15">1915</option>
<option value="16">1916</option>
<option value="17">1917</option>

<option value="18">1918</option>
<option value="19">1919</option>
<option value="20">1920</option>
<option value="21">1921</option>
<option value="22">1922</option>
<option value="23">1923</option>
<option value="24">1924</option>
<option value="25">1925</option>
<option value="26">1926</option>

<option value="27">1927</option>
<option value="28">1928</option>
<option value="29">1929</option>
<option value="30">1930</option>
<option value="31">1931</option>
<option value="32">1932</option>
<option value="33">1933</option>
<option value="34">1934</option>
<option value="35">1935</option>

<option value="36">1936</option>
<option value="37">1937</option>
<option value="38">1938</option>
<option value="39">1939</option>
<option value="40">1940</option>
<option value="41">1941</option>
<option value="42">1942</option>
<option value="43">1943</option>
<option value="44">1944</option>

<option value="45">1945</option>
<option value="46">1946</option>
<option value="47">1947</option>
<option value="48">1948</option>
<option value="49">1949</option>
<option value="50">1950</option>
<option value="51">1951</option>
<option value="52">1952</option>
<option value="53">1953</option>

<option value="54">1954</option>
<option value="55">1955</option>
<option value="56">1956</option>
<option value="57">1957</option>
<option value="58">1958</option>
<option value="59">1959</option>
<option value="60">1960</option>
<option value="61">1961</option>
<option value="62">1962</option>

<option value="63">1963</option>
<option value="64">1964</option>
<option value="65">1965</option>
<option value="66">1966</option>
<option value="67">1967</option>
<option value="68">1968</option>
<option value="69">1969</option>
<option value="70">1970</option>
<option value="71">1971</option>

<option value="72">1972</option>
<option value="73">1973</option>
<option value="74">1974</option>
<option value="75">1975</option>
<option value="76">1976</option>
<option value="77">1977</option>
<option value="78">1978</option>
<option value="79">1979</option>
<option value="80" selected="true">1980</option>

<option value="81">1981</option>
<option value="82">1982</option>
<option value="83">1983</option>
<option value="84">1984</option>
<option value="85">1985</option>
<option value="86">1986</option>
<option value="87">1987</option>
<option value="88">1988</option>
<option value="89">1989</option>

<option value="90">1990</option>
<option value="91">1991</option>
<option value="92">1992</option>
<option value="93">1993</option>
<option value="94">1994</option>
<option value="95">1995</option>
<option value="96">1996</option>
<option value="97">1997</option>
<option value="98">1998</option>
<option value="99">1999</option>

<option value="00">2000</option>
<option value="01">2001</option>
<option value="02">2002</option>
<option value="03">2003</option>
<option value="04">2004</option>
<option value="05">2005</option>
<option value="06">2006</option>
<option value="07">2007</option>
<option value="08">2008</option>
<option value="09">2009</option>
</select>

    </td>
    <td>

<select name="month">
<option value="01">01</option>
<option value="02">02</option>
<option value="03">03</option>
<option value="04">04</option>
<option value="05">05</option>
<option value="06">06</option>
<option value="07">07</option>
<option value="08">08</option>
<option value="09">09</option>
<option value="10">10</option>
<option value="11">11</option>
<option value="12">12</option>
</select>

    </td>
    <td>

<select name="day">
<option value="01">01</option>
<option value="02">02</option>
<option value="03">03</option>
<option value="04">04</option>
<option value="05">05</option>
<option value="06">06</option>
<option value="07">07</option>
<option value="08">08</option>
<option value="09">09</option>
<option value="10">10</option>

<option value="11">11</option>
<option value="12">12</option>
<option value="13">13</option>
<option value="14">14</option>
<option value="15">15</option>
<option value="16">16</option>
<option value="17">17</option>
<option value="18">18</option>
<option value="19">19</option>
<option value="20">20</option>

<option value="21">21</option>
<option value="22">22</option>
<option value="23">23</option>
<option value="24">24</option>
<option value="25">25</option>
<option value="26">26</option>
<option value="27">27</option>
<option value="28">28</option>
<option value="29">29</option>
<option value="30">30</option>

<option value="31">31</option>
</select>

-
    </td>
    <td>

<input type="text" name="birthnumber" value="" maxlength="3" size="3"<?php echo $sovix__close_tag; ?>>
<input type="submit" value="Calculate controlnumber"<?php echo $sovix__close_tag; ?>>

    </td>
  </tr>
</table>

</form>

<?php
$year=$_POST['year'];
$month=$_POST['month'];
$day=$_POST['day'];
$birthnumber=$_POST['birthnumber'];

$year_calc1=2*$year{0};
$year_calc2=1*$year{1};
$month_calc1=2*$month{0};
$month_calc2=1*$month{1};
$day_calc1=2*$day{0};
$day_calc2=1*$day{1};
$birthnumber_calc1=2*$birthnumber{0};
$birthnumber_calc2=1*$birthnumber{1};
$birthnumber_calc3=2*$birthnumber{2};

$numbersum=(
substr($year_calc1, 0, 1) + substr($year_calc1, 1, 1) +
substr($year_calc2, 0, 1) + substr($year_calc2, 1, 1) +
substr($month_calc1, 0, 1) + substr($month_calc1, 1, 1) +
substr($month_calc2, 0, 1) + substr($month_calc2, 1, 1) +
substr($day_calc1, 0, 1) + substr($day_calc1, 1, 1) +
substr($day_calc2, 0, 1) + substr($day_calc2, 1, 1) +
substr($birthnumber_calc1, 0, 1) + substr($birthnumber_calc1, 1, 1) +
substr($birthnumber_calc2, 0, 1) + substr($birthnumber_calc2, 1, 1) +
substr($birthnumber_calc3, 0, 1) + substr($birthnumber_calc3, 1, 1)
);
$last_digit_in_numbersum=substr($numbersum, 1, 2);
$controlnumber=10-$last_digit_in_numbersum;
if ($controlnumber=="10") $controlnumber="0";

  echo "<p>";

if (isset($birthnumber) && !ctype_digit($birthnumber)) { echo "* Enter digits<br$sovix__close_tag>"; $approve="n"; }
if (isset($birthnumber) && strlen($birthnumber) != 3) { echo "* To few characters<br$sovix__close_tag>"; $approve="n"; }

if (isset($birthnumber) && $approve!="n") {
  if ($birthnumber % 2) echo "Male: "; else echo "Female: ";
  echo "$year$month$day-$birthnumber$controlnumber</p>
<p>Calculated with Luhn algorithm.</p>";
 }
?>
    </td>
  </tr>
</table>

    <strong>Its not illegal to figure out the control number in personal number. The swedish government, Skatteverket provide the information how to do this in their brochure SKV 704 that can be found on their website, <a href="http://www.skatteverket.se/">skatteverket.se</a>.


<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6-rc4.tar.gz: sovix-0.0.1.6-rc4/websrc/IDC.php <==
<?php /* Copyright (C) 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2007, 2008 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<p>Swedish personal number calculator</p>

<table cellspacing="0" cellpadding="0">
  <tr>
    <td>
<form method='post'>

<table>
  <tr>
    <td>Year</td>
    <td>Month</td>
    <td>Day</td>
  <td>Birthnumber (odd third digit for males)</td>
  </tr>
  <tr>
    <td>

<select name="year">

			<option value="10">1910</option>
<option value="11">1911</option>
<option value="12">1912</option>
<option value="13">1913</option>
<option value="14">1914</option>
<option value="15">1915</option>
<option value="16">1916</option>
<option value="17">1917</option>

<option value="18">1918</option>
<option value="19">1919</option>
<option value="20">1920</option>
<option value="21">1921</option>
<option value="22">1922</option>
<option value="23">1923</option>
<option value="24">1924</option>
<option value="25">1925</option>
<option value="26">1926</option>

<option value="27">1927</option>
<option value="28">1928</option>
<option value="29">1929</option>
<option value="30">1930</option>
<option value="31">1931</option>
<option value="32">1932</option>
<option value="33">1933</option>
<option value="34">1934</option>
<option value="35">1935</option>

<option value="36">1936</option>
<option value="37">1937</option>
<option value="38">1938</option>
<option value="39">1939</option>
<option value="40">1940</option>
<option value="41">1941</option>
<option value="42">1942</option>
<option value="43">1943</option>
<option value="44">1944</option>

<option value="45">1945</option>
<option value="46">1946</option>
<option value="47">1947</option>
<option value="48">1948</option>
<option value="49">1949</option>
<option value="50">1950</option>
<option value="51">1951</option>
<option value="52">1952</option>
<option value="53">1953</option>

<option value="54">1954</option>
<option value="55">1955</option>
<option value="56">1956</option>
<option value="57">1957</option>
<option value="58">1958</option>
<option value="59">1959</option>
<option value="60">1960</option>
<option value="61">1961</option>
<option value="62">1962</option>

<option value="63">1963</option>
<option value="64">1964</option>
<option value="65">1965</option>
<option value="66">1966</option>
<option value="67">1967</option>
<option value="68">1968</option>
<option value="69">1969</option>
<option value="70">1970</option>
<option value="71">1971</option>

<option value="72">1972</option>
<option value="73">1973</option>
<option value="74">1974</option>
<option value="75">1975</option>
<option value="76">1976</option>
<option value="77">1977</option>
<option value="78">1978</option>
<option value="79">1979</option>
<option value="80" selected="true">1980</option>

<option value="81">1981</option>
<option value="82">1982</option>
<option value="83">1983</option>
<option value="84">1984</option>
<option value="85">1985</option>
<option value="86">1986</option>
<option value="87">1987</option>
<option value="88">1988</option>
<option value="89">1989</option>

<option value="90">1990</option>
<option value="91">1991</option>
<option value="92">1992</option>
<option value="93">1993</option>
<option value="94">1994</option>
<option value="95">1995</option>
<option value="96">1996</option>
<option value="97">1997</option>
<option value="98">1998</option>
<option value="99">1999</option>

<option value="00">2000</option>
<option value="01">2001</option>
<option value="02">2002</option>
<option value="03">2003</option>
<option value="04">2004</option>
<option value="05">2005</option>
<option value="06">2006</option>
<option value="07">2007</option>
<option value="08">2008</option>
<option value="09">2009</option>
</select>

    </td>
    <td>

<select name="month">
<option value="01">01</option>
<option value="02">02</option>
<option value="03">03</option>
<option value="04">04</option>
<option value="05">05</option>
<option value="06">06</option>
<option value="07">07</option>
<option value="08">08</option>
<option value="09">09</option>
<option value="10">10</option>
<option value="11">11</option>
<option value="12">12</option>
</select>

    </td>
    <td>

<select name="day">
<option value="01">01</option>
<option value="02">02</option>
<option value="03">03</option>
<option value="04">04</option>
<option value="05">05</option>
<option value="06">06</option>
<option value="07">07</option>
<option value="08">08</option>
<option value="09">09</option>
<option value="10">10</option>

<option value="11">11</option>
<option value="12">12</option>
<option value="13">13</option>
<option value="14">14</option>
<option value="15">15</option>
<option value="16">16</option>
<option value="17">17</option>
<option value="18">18</option>
<option value="19">19</option>
<option value="20">20</option>

<option value="21">21</option>
<option value="22">22</option>
<option value="23">23</option>
<option value="24">24</option>
<option value="25">25</option>
<option value="26">26</option>
<option value="27">27</option>
<option value="28">28</option>
<option value="29">29</option>
<option value="30">30</option>

<option value="31">31</option>
</select>

-
    </td>
    <td>

<input type="text" name="birthnumber" value="" maxlength="3" size="3"<?php echo $sovix__close_tag; ?>>
<input type="submit" value="Calculate controlnumber"<?php echo $sovix__close_tag; ?>>

    </td>
  </tr>
</table>

</form>

<?php
$year=$_POST['year'];
$month=$_POST['month'];
$day=$_POST['day'];
$birthnumber=$_POST['birthnumber'];

$year_calc1=2*$year{0};
$year_calc2=1*$year{1};
$month_calc1=2*$month{0};
$month_calc2=1*$month{1};
$day_calc1=2*$day{0};
$day_calc2=1*$day{1};
$birthnumber_calc1=2*$birthnumber{0};
$birthnumber_calc2=1*$birthnumber{1};
$birthnumber_calc3=2*$birthnumber{2};

$numbersum=(
substr($year_calc1, 0, 1) + substr($year_calc1, 1, 1) +
substr($year_calc2, 0, 1) + substr($year_calc2, 1, 1) +
substr($month_calc1, 0, 1) + substr($month_calc1, 1, 1) +
substr($month_calc2, 0, 1) + substr($month_calc2, 1, 1) +
substr($day_calc1, 0, 1) + substr($day_calc1, 1, 1) +
substr($day_calc2, 0, 1) + substr($day_calc2, 1, 1) +
substr($birthnumber_calc1, 0, 1) + substr($birthnumber_calc1, 1, 1) +
substr($birthnumber_calc2, 0, 1) + substr($birthnumber_calc2, 1, 1) +
substr($birthnumber_calc3, 0, 1) + substr($birthnumber_calc3, 1, 1)
);
$last_digit_in_numbersum=substr($numbersum, 1, 2);
$controlnumber=10-$last_digit_in_numbersum;
if ($controlnumber=="10") $controlnumber="0";

  echo "<p>";

if (isset($birthnumber) && !ctype_digit($birthnumber)) { echo "* Enter digits<br$sovix__close_tag>"; $approve="n"; }
if (isset($birthnumber) && strlen($birthnumber) != 3) { echo "* To few characters<br$sovix__close_tag>"; $approve="n"; }

if (isset($birthnumber) && $approve!="n") {
  if ($birthnumber % 2) echo "Male: "; else echo "Female: ";
  echo "$year$month$day-$birthnumber$controlnumber</p>
<p>Calculated with Luhn algorithm.</p>";
 }
?>
    </td>
  </tr>
</table>

    <strong>Its not illegal to figure out the control number in personal number. The swedish government, Skatteverket provide the information how to do this in their brochure SKV 704 that can be found on their website, <a href="http://www.skatteverket.se/">skatteverket.se</a>.</strong>


<?php require_once "$sovix__directory__src/footer.inc"; ?>
